import { select, csv, scaleLinear, max, scaleBand } from 'd3';

const svg = select('svg');

const height = parseFloat(svg.attr('height'));
const width = parseFloat(svg.attr('width'));

const render = data => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = { top: 20, right: 20, bottom: 20, left: 20 };
  
  const xScale = scaleLinear()
    .domain([0, max(data, d => d.population)])
    .range([0, width]);
  
  const yScale = scaleBand()
    .domain(data.map(d => d.country))
    .range([0. height]);
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin,top})`);
  
  svg.selectAll('rect').data(data)
    .enter().append('rect')
      .attr('y', d => xScale(d.country))
      .attr('width', d => xScale(d.population))
      .attr('height', yScale.bandwidth());
};

csv('data.csv').then(data => {
  data.forEach(d => {
    d.population = +d.population * 1000;
  });
  render(data);
});
